@@ -1,5 +1,7 @@
 """
-Main interface for neptune service client paginators.
+Type annotations for neptune service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -44,13 +46,13 @@ Usage::
     describe_pending_maintenance_actions_paginator: DescribePendingMaintenanceActionsPaginator = client.get_paginator("describe_pending_maintenance_actions")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_neptune.type_defs import (
+from .literals import SourceType
+from .type_defs import (
     DBClusterEndpointMessageTypeDef,
     DBClusterMessageTypeDef,
     DBClusterParameterGroupDetailsTypeDef,
@@ -70,12 +72,6 @@ from mypy_boto3_neptune.type_defs import (
     PendingMaintenanceActionsMessageTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "DescribeDBClusterEndpointsPaginator",
     "DescribeDBClusterParameterGroupsPaginator",
@@ -97,7 +93,7 @@ __all__ = (
 
 class DescribeDBClusterEndpointsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusterEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterEndpoints)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterEndpoints)[Show boto3-stubs documentation](./paginators.md#describedbclusterendpointspaginator)
     """
 
     def paginate(
@@ -108,13 +104,14 @@ class DescribeDBClusterEndpointsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBClusterEndpointMessageTypeDef]:
         """
-        [DescribeDBClusterEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterEndpoints.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterEndpoints.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbclusterendpointspaginator)
         """
 
 
 class DescribeDBClusterParameterGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusterParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups)[Show boto3-stubs documentation](./paginators.md#describedbclusterparametergroupspaginator)
     """
 
     def paginate(
@@ -124,13 +121,14 @@ class DescribeDBClusterParameterGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBClusterParameterGroupsMessageTypeDef]:
         """
-        [DescribeDBClusterParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameterGroups.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbclusterparametergroupspaginator)
         """
 
 
 class DescribeDBClusterParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusterParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters)[Show boto3-stubs documentation](./paginators.md#describedbclusterparameterspaginator)
     """
 
     def paginate(
@@ -141,13 +139,14 @@ class DescribeDBClusterParametersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBClusterParameterGroupDetailsTypeDef]:
         """
-        [DescribeDBClusterParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterParameters.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbclusterparameterspaginator)
         """
 
 
 class DescribeDBClusterSnapshotsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusterSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots)[Show boto3-stubs documentation](./paginators.md#describedbclustersnapshotspaginator)
     """
 
     def paginate(
@@ -161,13 +160,14 @@ class DescribeDBClusterSnapshotsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBClusterSnapshotMessageTypeDef]:
         """
-        [DescribeDBClusterSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusterSnapshots.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbclustersnapshotspaginator)
         """
 
 
 class DescribeDBClustersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters)[Show boto3-stubs documentation](./paginators.md#describedbclusterspaginator)
     """
 
     def paginate(
@@ -177,13 +177,14 @@ class DescribeDBClustersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBClusterMessageTypeDef]:
         """
-        [DescribeDBClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBClusters.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbclusterspaginator)
         """
 
 
 class DescribeDBEngineVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions)[Show boto3-stubs documentation](./paginators.md#describedbengineversionspaginator)
     """
 
     def paginate(
@@ -198,13 +199,14 @@ class DescribeDBEngineVersionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBEngineVersionMessageTypeDef]:
         """
-        [DescribeDBEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBEngineVersions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbengineversionspaginator)
         """
 
 
 class DescribeDBInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances)[Show boto3-stubs documentation](./paginators.md#describedbinstancespaginator)
     """
 
     def paginate(
@@ -214,13 +216,14 @@ class DescribeDBInstancesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBInstanceMessageTypeDef]:
         """
-        [DescribeDBInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBInstances.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbinstancespaginator)
         """
 
 
 class DescribeDBParameterGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups)[Show boto3-stubs documentation](./paginators.md#describedbparametergroupspaginator)
     """
 
     def paginate(
@@ -230,13 +233,14 @@ class DescribeDBParameterGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBParameterGroupsMessageTypeDef]:
         """
-        [DescribeDBParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameterGroups.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbparametergroupspaginator)
         """
 
 
 class DescribeDBParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters)[Show boto3-stubs documentation](./paginators.md#describedbparameterspaginator)
     """
 
     def paginate(
@@ -247,13 +251,14 @@ class DescribeDBParametersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBParameterGroupDetailsTypeDef]:
         """
-        [DescribeDBParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBParameters.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbparameterspaginator)
         """
 
 
 class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups)[Show boto3-stubs documentation](./paginators.md#describedbsubnetgroupspaginator)
     """
 
     def paginate(
@@ -263,13 +268,14 @@ class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBSubnetGroupMessageTypeDef]:
         """
-        [DescribeDBSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeDBSubnetGroups.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describedbsubnetgroupspaginator)
         """
 
 
 class DescribeEngineDefaultParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEngineDefaultParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters)[Show boto3-stubs documentation](./paginators.md#describeenginedefaultparameterspaginator)
     """
 
     def paginate(
@@ -279,13 +285,14 @@ class DescribeEngineDefaultParametersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeEngineDefaultParametersResultTypeDef]:
         """
-        [DescribeEngineDefaultParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeEngineDefaultParameters.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describeenginedefaultparameterspaginator)
         """
 
 
 class DescribeEventSubscriptionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEventSubscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions)[Show boto3-stubs documentation](./paginators.md#describeeventsubscriptionspaginator)
     """
 
     def paginate(
@@ -295,26 +302,20 @@ class DescribeEventSubscriptionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[EventSubscriptionsMessageTypeDef]:
         """
-        [DescribeEventSubscriptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeEventSubscriptions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describeeventsubscriptionspaginator)
         """
 
 
 class DescribeEventsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeEvents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeEvents)[Show boto3-stubs documentation](./paginators.md#describeeventspaginator)
     """
 
     def paginate(
         self,
         SourceIdentifier: str = None,
-        SourceType: Literal[
-            "db-instance",
-            "db-parameter-group",
-            "db-security-group",
-            "db-snapshot",
-            "db-cluster",
-            "db-cluster-snapshot",
-        ] = None,
+        SourceType: SourceType = None,
         StartTime: datetime = None,
         EndTime: datetime = None,
         Duration: int = None,
@@ -323,13 +324,14 @@ class DescribeEventsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[EventsMessageTypeDef]:
         """
-        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeEvents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeEvents.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describeeventspaginator)
         """
 
 
 class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions)[Show boto3-stubs documentation](./paginators.md#describeorderabledbinstanceoptionspaginator)
     """
 
     def paginate(
@@ -343,13 +345,14 @@ class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[OrderableDBInstanceOptionsMessageTypeDef]:
         """
-        [DescribeOrderableDBInstanceOptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribeOrderableDBInstanceOptions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describeorderabledbinstanceoptionspaginator)
         """
 
 
 class DescribePendingMaintenanceActionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribePendingMaintenanceActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions)[Show boto3-stubs documentation](./paginators.md#describependingmaintenanceactionspaginator)
     """
 
     def paginate(
@@ -359,5 +362,6 @@ class DescribePendingMaintenanceActionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[PendingMaintenanceActionsMessageTypeDef]:
         """
-        [DescribePendingMaintenanceActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Paginator.DescribePendingMaintenanceActions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describependingmaintenanceactionspaginator)
         """
