@@ -1,5 +1,7 @@
 """
-Main interface for neptune service client waiters.
+Type annotations for neptune service client waiters.
+
+[Open documentation](./waiters.md)
 
 Usage::
 
@@ -22,14 +24,14 @@ from typing import List
 
 from botocore.waiter import Waiter as Boto3Waiter
 
-from mypy_boto3_neptune.type_defs import FilterTypeDef, WaiterConfigTypeDef
+from .type_defs import FilterTypeDef, WaiterConfigTypeDef
 
 __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 
 
 class DBInstanceAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Waiter.DBInstanceAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Waiter.db_instance_available)[Show boto3-stubs documentation](./waiters.md#dbinstanceavailablewaiter)
     """
 
     def wait(
@@ -41,13 +43,14 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Waiter.DBInstanceAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Waiter.DBInstanceAvailableWaiter)
+        [Show boto3-stubs documentation](./waiters.md#dbinstanceavailable)
         """
 
 
 class DBInstanceDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Waiter.DBInstanceDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Waiter.db_instance_deleted)[Show boto3-stubs documentation](./waiters.md#dbinstancedeletedwaiter)
     """
 
     def wait(
@@ -59,5 +62,6 @@ class DBInstanceDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/neptune.html#Neptune.Waiter.DBInstanceDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/neptune.html#Neptune.Waiter.DBInstanceDeletedWaiter)
+        [Show boto3-stubs documentation](./waiters.md#dbinstancedeleted)
         """
